@@ -17,23 +17,23 @@ function(Y,T,kernel){
 		B = t(XX)%*%TT%*%t(TT)%*%XX / n
 	
 		# Eigendecomposition of S^-1 * B
-	eig = eigen(solve(S)%*%B)
-	U[,1] = matrix(Re(eig$vec[,1]),ncol=1)
+		eig = eigen(solve(S)%*%B)
+		U[,1] = matrix(Re(eig$vec[,1]),ncol=1)
 
 if (d>1) for (k in 2:d){ 
-	  W = as.matrix(U[,-c(k:d)])  
-	  base = diag(p)
-	  base <- as.matrix(base[,1:(p-k+1)])
-	  W =  cbind(W,base)
-	}
+			W = as.matrix(U[,-c(k:d)])  
+			base = diag(p)
+			base <- as.matrix(base[,1:(p-k+1)])
+			W =  cbind(W,base)
+	
 	v <- W  
 
-	# start of the gram-schmidt algorithm
-	for(l in 2:p){
-          proj <- c(crossprod(W[,l],v[,1:(l-1)])) / diag(crossprod(v[,1:(l-1)]))
-	  v[,l] <- matrix(W[,l],ncol=1) - matrix(v[,1:(l-1)],nrow=p) %*%  matrix(proj,ncol=1)
-	  v[,l] <- v[,l] /  sqrt(crossprod(v[,l]))
-	}
+		# start of the gram-schmidt algorithm
+		for (l in 2:p){
+				proj <- c(crossprod(W[,l],v[,1:(l-1)])) / diag(crossprod(v[,1:(l-1)]))
+				v[,l] <- matrix(W[,l],ncol=1) - matrix(v[,1:(l-1)],nrow=p) %*%  matrix(proj,ncol=1)
+				v[,l] <- v[,l] /  sqrt(crossprod(v[,l]))
+		}
 
 
 	P   = v[,k:ncol(v)] 
@@ -44,6 +44,8 @@ if (d>1) for (k in 2:d){
 	Umax = matrix(Re(eig$vec[,1]),ncol=1) 
         U[,k]= P%*%Umax	
 	}
-U
+}
+if (d==1) {U = U[,1]} 
+as.matrix(U)
 }
 
